pub(crate) struct SelectorSchedule<'a> {
pub(crate) hardfork: TempoHardfork,
pub(crate) added: &'a [[u8; 4]],
pub(crate) dropped: &'a [[u8; 4]],
}Expand description
A selector schedule at a given hardfork boundary.
Before the hardfork activates, selectors in added are treated as unknown.
After it activates, selectors in dropped are treated as unknown.
Fields
hardfork: TempoHardforkadded: &'a [[u8; 4]]dropped: &'a [[u8; 4]]Implementations
Sourceimpl<'a> SelectorSchedule<'a>
impl<'a> SelectorSchedule<'a>
Sourcepub(crate) const fn new(hardfork: TempoHardfork) -> Self
pub(crate) const fn new(hardfork: TempoHardfork) -> Self
Creates a new schedule anchored at hardfork with no selectors registered yet.
Sourcepub(crate) const fn with_added(self, selectors: &'a [[u8; 4]]) -> Self
pub(crate) const fn with_added(self, selectors: &'a [[u8; 4]]) -> Self
Registers selectors that are introduced at this hardfork boundary.
These selectors are treated as unknown BEFORE hardfork activates.
Sourcepub(crate) const fn with_dropped(self, selectors: &'a [[u8; 4]]) -> Self
pub(crate) const fn with_dropped(self, selectors: &'a [[u8; 4]]) -> Self
Registers selectors that are removed at this hardfork boundary.
These selectors are treated as unknown ONCE hardfork activates.